<?php

App::uses('FaqsAppController', 'Faqs.Controller');

class FaqsController extends FaqsAppController {

/**
 * Before filter
 *
 * @return void
 */
	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow([
			'index',
		]);
	}

/**
 * FAQs page
 *
 * @return void
 */
	public function index() {
		$Model = $this->{$this->modelClass};

		// Get the page details for headers / meta data
		if (Configure::check('Faqs.page_ids.index')) {
			$this->assignPage(Configure::read('Faqs.page_ids.index'));
		}

		$this->set('faqs', $this->Faq->getFaqs());

		$this->view = 'Faqs.Faqs/index';
	}

/**
 * Populate admin lookups
 *
 * @return void
 */
	protected function _adminPopulateLookups() {
		$Model = $this->{$this->modelClass};
		$faqCategories = $Model->FaqCategory->find('list');
		$this->set(compact('faqCategories'));
	}

/**
 * Admin index columns whitelist
 *
 * @return array
 */
	protected function _adminIndexColumnsWhitelist() {
		$columns = parent::_adminIndexColumnsWhitelist();
		$columns[] = 'Faq.answer';
		return $columns;
	}

/**
 * Admin form fields
 *
 * @return array
 */
	protected function _adminFormFields() {
		$formFields = parent::_adminFormFields();

		// if we are not using faq categories then unset the select field
		if (
			Configure::read('Faqs.has_categories') !== true &&
			isset($formFields[$this->{$this->modelClass}->alias . '.faq_category_id'])
		) {
			unset($formFields[$this->{$this->modelClass}->alias . '.faq_category_id']);
		}

		return $formFields;
	}

/**
 * Admin edit
 *
 * @param int $id FAQ ID
 * @return void
 */
	public function admin_edit($id = null) {
		if (Configure::read('Faqs.has_categories') === true) {
			$this->{$this->modelClass}->validate = array_merge(
				$this->{$this->modelClass}->validate,
				[
					'faq_category_id' => [
						'required' => [
							'rule' => 'notBlank',
							'message' => 'Please tag a faq category'
						]
					]
				]
			);
		}

		return parent::admin_edit($id);
	}

}
